@@ -32,6 +32,7 @@ from collections import OrderedDict
 from contextlib import suppress
 from copy import copy
 from itertools import count
+from operator import attrgetter
 from os import getenv
 
 from . import __version__, __release_date__
@@ -41,12 +42,12 @@ from .flowable import StaticGroupedFlowables
 from .language import EN
 from .layout import (Container, ReflowRequired,
                      BACKGROUND, CONTENT, HEADER_FOOTER)
-from .number import format_number
+from .number import NumberFormatBase, format_number
 from .reference import ReferenceType
 from .strings import Strings
-from .style import StyleLog
+from .style import Match, StyleLog, ZERO_SPECIFICITY
 from .text import StyledText
-from .util import DEFAULT, RefKeyDictionary
+from .util import DEFAULT, WeakMutableKeyDictionary
 from .warnings import warn
 
 
@@ -58,14 +59,12 @@ class DocumentTree(StaticGroupedFlowables):
 
     Args:
         flowables (list[Flowable]): the list of top-level flowables
-        source_root (Path): path used to locate images and include in logging
-            and error and warnings.
         options (Reader): frontend-specific options
 
     """
 
-    def __init__(self, flowables, options=None):
-        super().__init__(flowables)
+    def __init__(self, flowables, options=None, style=None, source=None):
+        super().__init__(flowables, style=style, source=source)
         self.options = options
 
 
@@ -77,6 +76,12 @@ class PageType(OptionSet):
     values = 'left', 'right', 'any'
 
 
+class PageNumberFormat(NumberFormatBase):
+    """How (or if) page numbers are displayed"""
+
+    values = NumberFormatBase.values + ('continue', )
+
+
 class Page(Container):
     """A single page in a document.
 
@@ -105,8 +110,7 @@ class Page(Container):
         document = self.document_part.document
         backend_document = document.backend_document
         self.backend_page = document.backend.Page(backend_document,
-                                                  width, height, self.number,
-                                                  self.number_format)
+                                                  width, height, self)
         self._empty = True
         super().__init__('PAGE', None, 0, 0, width, height)
 
@@ -135,7 +139,7 @@ class Page(Container):
                 break
             if first_page.document_part is not self.document_part:
                 continue
-            elif first_page.number == self.number:
+            elif first_page is self:
                 return section
             elif first_page.number > self.number:
                 break
@@ -147,9 +151,17 @@ class Page(Container):
     def number_format(self):
         return self.document_part.page_number_format
 
+    @property
+    def page_number_prefix(self):
+        prefix = self.document_part.get_config_value('page_number_prefix',
+                                                     self.document)
+        return prefix.to_string(self) if prefix else None
+
     @property
     def formatted_number(self):
-        return format_number(self.number, self.number_format)
+        page_number = format_number(self.number, self.number_format)
+        prefix = self.page_number_prefix
+        return prefix + page_number if prefix else page_number
 
     def render(self):
         super().render(BACKGROUND)
@@ -226,6 +238,8 @@ class Document(object):
         """`backend` specifies the backend to use for rendering the document."""
         super().__init__()
         self._print_version_and_license()
+        self._no_cache = getenv('RINOH_NO_CACHE', '0') != '0'
+        self._single_pass = getenv('RINOH_SINGLE_PASS', '0') != '0'
         self.front_matter = []
         self.supporting_matter = {}
         self.document_tree = document_tree
@@ -239,10 +253,11 @@ class Document(object):
         self.metadata = Metadata(self, date=datetime.date.today())
         self.counters = {}             # counters for Headings, Figures, Tables
         self.elements = OrderedDict()  # mapping id's to flowables
-        self.ids_by_element = RefKeyDictionary()    # mapping elements to id's
+        self.ids_by_element = WeakMutableKeyDictionary()    # mapping elements to id's
         self.references = {}           # mapping id's to reference data
         self.page_elements = {}        # mapping id's to pages
         self.page_references = {}      # mapping id's to page numbers
+        self._styled_matches = WeakMutableKeyDictionary()   # cache matching styles
         self._sections = []
         self.index_entries = {}
         self._glossary = {}
@@ -296,6 +311,25 @@ to the terms of the GNU Affero General Public License version 3.''')
                 raise
             return default
 
+    def get_matches(self, styled):
+        styled_matches = self._styled_matches
+        try:
+            return styled_matches[styled]
+        except KeyError:
+            stylesheet = self.stylesheet
+            matches = sorted(stylesheet.find_matches(styled, self),
+                             key=attrgetter('specificity'), reverse=True)
+            last_match = Match(None, ZERO_SPECIFICITY)
+            for match in matches:
+                if (match.specificity == last_match.specificity
+                        and match.style_name != last_match.style_name):
+                    styled.warn('Multiple selectors match with the same '
+                              'specificity. See the style log for details.')
+                match.stylesheet = stylesheet.find_source(match.style_name)
+                last_match = match
+            styled_matches[styled] = matches
+            return matches
+
     def set_glossary(self, term, definition):
         try:
             existing_definition = self._glossary[term]
@@ -314,6 +348,9 @@ to the terms of the GNU Affero General Public License version 3.''')
 
     def _load_cache(self, filename):
         """Load the cached page references from `<filename>.ptc`."""
+        if self._no_cache:
+            print('Loading/saving of the references cache is disabled')
+            return {}, {}
         cache_path = filename.with_suffix(self.CACHE_EXTENSION)
         try:
             with cache_path.open('rb') as file:
@@ -325,6 +362,8 @@ to the terms of the GNU Affero General Public License version 3.''')
 
     def _save_cache(self, filename):
         """Save the current state of the page references to `<filename>.rtc`"""
+        if self._no_cache:
+            return
         cache_path = Path(filename).with_suffix(self.CACHE_EXTENSION)
         with cache_path.open('wb') as file:
             cache = (self.part_page_counts, self.page_references)
@@ -380,7 +419,7 @@ to the terms of the GNU Affero General Public License version 3.''')
                 if (self.part_page_counts == prev_page_counts
                         and self.page_references == prev_page_refs):
                     break
-                if getenv('RINOH_SINGLE_PASS', '0') != '0':
+                if self._single_pass:
                     print('Stopping after first rendering pass.')
                     break
                 print('Not yet converged, rendering again...')
@@ -390,7 +429,8 @@ to the terms of the GNU Affero General Public License version 3.''')
             self._create_outlines(self.backend_document)
             if filename:
                 self._save_cache(filename_root)
-                self.style_log.write_log(filename_root)
+                self.style_log.write_log(self.document_tree.source_root,
+                                         filename_root)
                 print('Writing output: {}'.format(filename))
             self.backend_document.write(file)
         finally:
@@ -410,14 +450,14 @@ to the terms of the GNU Affero General Public License version 3.''')
         part_page_count = PartPageCount()
         last_number_format = None
         for part_template in self.part_templates:
-            part = part_template.document_part(self)
+            part = part_template.document_part(self, last_number_format)
             if part is None:
                 continue
-            if part_template.page_number_format != last_number_format:
+            if part.get_config_value('page_number_format', self) != 'continue':
                 part_page_count = PartPageCount()
             part_page_count += part.render(part_page_count.count + 1)
             part_page_counts[part_template.name] = part_page_count
-            last_number_format = part_template.page_number_format
+            last_number_format = part.page_number_format
         sys.stdout.write('\n')     # for the progress indicator
         return part_page_counts
 
