@@ -15,7 +15,7 @@ PLATFORM_CUSTOM = 4
 LANGUAGE_WINDOWS_EN_US = 0x0409
 
 NAME_COPYRIGHT = 0
-NAME_FAMILTY = 1
+NAME_FAMILY = 1
 NAME_SUBFAMILY = 2
 NAME_UID = 3
 NAME_FULL = 4
@@ -29,8 +29,11 @@ NAME_VENDOR_URL = 11
 NAME_DESIGNER_URL = 12
 NAME_LICENSE = 13
 NAME_LICENSE_URL = 14
-NAME_PREFERRED_FAMILY = 16
-NAME_PREFERRED_SUBFAMILY = 17
+NAME_TYPOGRAPHIC_FAMILY = 16
+NAME_TYPOGRAPHIC_SUBFAMILY = 17
+# ...
+NAME_WWS_FAMILY = 21
+NAME_WWS_SUBFAMILY = 22
 # ...
 
 UNICODE_1_0 = 0
