@@ -48,8 +48,8 @@ class Inline(DocutilsInlineNode):
         return self.process_content(style=self.style_from_class)
 
 
-class Document(DocutilsBodyNode):
-    pass
+class Document(DocutilsGroupingNode):
+    grouped_flowables_class = rt.DocumentTree
 
 
 class DocInfo(DocutilsBodyNode):
@@ -604,19 +604,29 @@ class Image(DocutilsBodyNode, DocutilsInlineNode):
     def image_path(self):
         return self.get('uri')
 
-    def build_flowable(self):
-        width_string = self.get('width')
+    @property
+    def options(self):
+        width = convert_quantity(self.get('width'))
+        height = convert_quantity(self.get('height'))
         align = self.get('align')
-        return rt.Image(self.image_path, scale=self.get('scale', 100) / 100,
-                        width=convert_quantity(width_string), align=align)
+        scale = self.get('scale', 100) / 100
+        if scale != 1 and (width or height):
+            width = width * scale if width else None
+            height = height * scale if height else None
+            scale = 1
+        return dict(align=align, width=width, height=height, scale=scale)
+
+    def build_flowable(self):
+        return rt.Image(self.image_path, **self.options)
 
     ALIGN_TO_BASELINE = {'bottom': 0,
                          'middle': 50*PERCENT,
                          'top': 100*PERCENT}
 
     def build_styled_text(self):
-        baseline = self.ALIGN_TO_BASELINE.get(self.get('align'))
-        return rt.InlineImage(self.image_path, baseline=baseline)
+        options = self.options
+        baseline = self.ALIGN_TO_BASELINE.get(options.pop('align'))
+        return rt.InlineImage(self.image_path, baseline=baseline, **options)
 
 
 class Figure(DocutilsGroupingNode):
@@ -645,7 +655,7 @@ class Transition(DocutilsBodyNode):
         return rt.HorizontalRule()
 
 
-RE_LENGTH_PERCENT_UNITLESS = re.compile(r'^(?P<value>\d+)(?P<unit>[a-z%]*)$')
+RE_LENGTH_PERCENT_UNITLESS = re.compile(r'^(?P<value>\d+\.?\d*)(?P<unit>[a-z%]*)$')
 
 # TODO: warn on px or when no unit is supplied
 DOCUTILS_UNIT_TO_DIMENSION = {'': PT,    # assume points for unitless quantities
@@ -654,7 +664,7 @@ DOCUTILS_UNIT_TO_DIMENSION = {'': PT,    # assume points for unitless quantities
                               'mm': MM,
                               'pt': PT,
                               'pc': PICA,
-                              'px': DimensionUnit(1 / 100 * INCH, 'px'),
+                              'px': DimensionUnit(1 / 96 * INCH, 'px'),
                               '%': PERCENT,
                               'em': None,
                               'ex': None}
