@@ -9,24 +9,22 @@
 import os
 
 from ast import literal_eval
-from functools import partial
 from pathlib import Path
 from token import LPAR, RPAR, NAME, EQUAL, NUMBER, ENDMARKER,  STRING, COMMA
 
-from .attribute import (Attribute, AcceptNoneAttributeType, Integer,
-                        OptionSet, AttributesDictionary, ParseError)
-from .color import RED
+from .attribute import (Attribute, AttributesDictionary, OverrideDefault,
+                        AcceptNoneAttributeType, OptionSet, Integer,
+                        ParseError)
 from .dimension import Dimension, PERCENT
 from .flowable import (Flowable, FlowableState, HorizontalAlignment,
                        FlowableWidth, StaticGroupedFlowables,
                        GroupedFlowablesStyle, Float, FloatStyle)
 from .inline import InlineFlowable
 from .layout import ContainerOverflow, EndOfContainer
-from .number import NumberedParagraph, NumberedParagraphStyle, format_number
-from .paragraph import Paragraph
-from .reference import ReferenceType
+from .number import NumberFormat
+from .paragraph import StaticParagraph, Paragraph, ParagraphStyle
 from .structure import ListOf, ListOfSection
-from .text import MixedStyledText, SingleStyledText, TextStyle, StyledText
+from .text import MixedStyledText, SingleStyledText, TextStyle, ErrorText
 from .util import posix_path, ReadAliasAttribute, PeekIterator
 
 
@@ -258,8 +256,8 @@ class ImageBase(Flowable):
             container.document.error = True
             message = "Error opening image file: {}".format(err)
             self.warn(message)
-            text = SingleStyledText(message, style=TextStyle(font_color=RED))
-            return Paragraph(text).flow(container, last_descender)
+            error = ErrorText(message)
+            return Paragraph(error).flow(container, last_descender)
         left, top = 0, float(container.cursor)
         width = self._width(container)
         try:
@@ -378,49 +376,23 @@ class BackgroundImage(_Image, AcceptNoneAttributeType):
                 'displayed')
 
 
-class CaptionStyle(NumberedParagraphStyle):
-    numbering_level = Attribute(Integer, 1, 'At which section level to '
-                                            'restart numbering')
-    number_separator = Attribute(StyledText, '.', 'Characters inserted between'
-                                 ' the section number and the caption number')
+class CaptionStyle(ParagraphStyle):
+    number_format = OverrideDefault(NumberFormat.NUMBER)
+    numbering_level = OverrideDefault(1)
 
 
-class Caption(NumberedParagraph):
+class Caption(StaticParagraph):
     style_class = CaptionStyle
+    has_title = True
 
     @property
     def referenceable(self):
         return self.parent
 
-    def prepare(self, flowable_target):
-        super().prepare(flowable_target)
-        document = flowable_target.document
-        get_style = partial(self.get_style, container=flowable_target)
-        category = self.referenceable.category
-        numbering_level = get_style('numbering_level')
-        section = self.section
-        while section and section.level > numbering_level:
-            section = section.parent.section
-        section_id = section.get_id(document, False) if section else None
-        category_counters = document.counters.setdefault(category, {})
-        category_counter = category_counters.setdefault(section_id, [])
-        category_counter.append(self)
-        number_format = get_style('number_format')
-        number = format_number(len(category_counter), number_format)
-        if section_id:
-            section_number = document.get_reference(section_id, 'number')
-            sep = get_style('number_separator') or SingleStyledText('')
-            number = section_number + sep.to_string(flowable_target) + number
-        reference = '{} {}'.format(category, number)
-        for id in self.referenceable.get_ids(document):
-            document.set_reference(id, ReferenceType.NUMBER, number)
-            document.set_reference(id, ReferenceType.REFERENCE, reference)
-            document.set_reference(id, ReferenceType.TITLE,
-                                   self.content.to_string(None))
-
     def text(self, container):
-        label = self.referenceable.category + ' ' + self.number(container)
-        return MixedStyledText(label + self.content, parent=self)
+        cat = self.referenceable.category
+        number = self.number(container)
+        return MixedStyledText([cat, ' ', number, self.content], parent=self)
 
 
 class FigureStyle(FloatStyle, GroupedFlowablesStyle):
