@@ -5,12 +5,7 @@
 # Use of this source code is subject to the terms of the GNU Affero General
 # Public License v3. See the LICENSE file or http://www.gnu.org/licenses/.
 
-"""
-Functions for formatting numbers:
 
-* :func:`format_number`: Format a number according to a given style.
-
-"""
 from copy import copy
 
 from .attribute import Attribute, OptionSet, Bool, ParseError
@@ -18,20 +13,31 @@ from .style import Style
 from .text import StyledText
 
 
-__all__ = ['NumberFormat', 'NumberStyle', 'Label', 'format_number']
+__all__ = ['NumberFormat', 'Label', 'LabelStyle', 'NumberStyle',
+           'format_number']
 
 
-class NumberFormat(OptionSet):
+# number: plain arabic numbers (1, 2, 3, ...)
+# lowercase character: lowercase letters (a, b, c, ..., aa, ab, ...)
+# uppercase character: uppercase letters (A, B, C, ..., AA, AB, ...)
+# lowercase roman: lowercase Roman numerals (i, ii, iii, iv, v, vi, ...)
+# uppercase roman: uppercase Roman numerals (I, II, III, IV, V, VI, ...)
+# symbol: symbols (*, †, ‡, §, ‖, ¶, #, **, *†, ...)
+
+
+class NumberFormatBase(OptionSet):
+    values = (None, 'number', 'symbol', 'lowercase character',
+              'uppercase character', 'lowercase roman', 'uppercase roman')
+
+
+class NumberFormat(NumberFormatBase):
     """How (or if) numbers are displayed
 
     Instead of a numbering format, it's possible to supply a custom label
-    (:class:`StyledText`) to show instead of the number.
+    (:class:`~.StyledText`) to show instead of the number.
 
     """
 
-    values = (None, 'number', 'symbol', 'lowercase character',
-              'uppercase character', 'lowercase roman', 'uppercase roman')
-
     @classmethod
     def check_type(cls, value):
         return super().check_type(value) or StyledText.check_type(value)
@@ -46,12 +52,33 @@ class NumberFormat(OptionSet):
             return StyledText.from_tokens(tokens, source)
 
 
-# number: plain arabic numbers (1, 2, 3, ...)
-# lowercase character: lowercase letters (a, b, c, ..., aa, ab, ...)
-# uppercase character: uppercase letters (A, B, C, ..., AA, AB, ...)
-# lowercase roman: lowercase Roman numerals (i, ii, iii, iv, v, vi, ...)
-# uppercase roman: uppercase Roman numerals (I, II, III, IV, V, VI, ...)
-# symbol: symbols (*, †, ‡, §, ‖, ¶, #, **, *†, ...)
+class LabelStyle(Style):
+    label_prefix = Attribute(StyledText, None, 'Text to prepend to the label')
+    label_suffix = Attribute(StyledText, None, 'Text to append to the label')
+    custom_label = Attribute(Bool, False, 'Use a custom label if specified')
+
+
+class Label(object):
+    """Mixin class that formats a label
+
+    Args:
+        custom_label (StyledText): a frontend can supply a custom label to use
+            instead of an automatically determined label (typically a number)
+
+    """
+
+    def __init__(self, custom_label=None):
+        self.custom_label = custom_label
+
+    def format_label(self, label, container):
+        prefix = self.get_style('label_prefix', container) or ''
+        suffix = self.get_style('label_suffix', container) or ''
+        return copy(prefix) + copy(label) + copy(suffix)
+
+
+class NumberStyle(LabelStyle):
+    number_format = Attribute(NumberFormat, 'number',
+                              'How numbers are formatted')
 
 
 def format_number(number, format):
@@ -105,32 +132,3 @@ FORMAT_NUMBER = {
     NumberFormat.SYMBOL: symbolize,
     NumberFormat.NONE: lambda number: ''
 }
-
-
-class LabelStyle(Style):
-    label_prefix = Attribute(StyledText, None, 'Text to prepend to the label')
-    label_suffix = Attribute(StyledText, None, 'Text to append to the label')
-    custom_label = Attribute(Bool, False, 'Use a custom label if specified')
-
-
-class Label(object):
-    """Mixin class that formats a label
-
-    Args:
-        custom_label (StyledText): a frontend can supply a custom label to use
-            instead of an automatically determined label (typically a number)
-
-    """
-
-    def __init__(self, custom_label=None):
-        self.custom_label = custom_label
-
-    def format_label(self, label, container):
-        prefix = self.get_style('label_prefix', container) or ''
-        suffix = self.get_style('label_suffix', container) or ''
-        return copy(prefix) + copy(label) + copy(suffix)
-
-
-class NumberStyle(LabelStyle):
-    number_format = Attribute(NumberFormat, 'number',
-                              'How numbers are formatted')
