@@ -128,7 +128,8 @@ class Heading(StaticParagraph):
 
     def flow_inner(self, container, descender, state=None, **kwargs):
         result = super().flow_inner(container, descender, state=state, **kwargs)
-        create_destination(self.section, container, True)
+        if not state.initial:
+            create_destination(self.section, container, True)
         return result
 
 
@@ -423,7 +424,7 @@ class HorizontalRule(Flowable):
 
     def render(self, container, descender, state, **kwargs):
         width = float(container.width)
-        line = Line((0, 0), (width, 0), style=PARENT_STYLE, parent=self)
+        line = Line((0, 0), (width, 0), parent=self)
         line.render(container)
         return width, 0, 0
 
