@@ -1,3 +1,4 @@
+from rinoh.document import DocumentTree
 from rinoh.style import StyledMatcher, SelectorByName
 from rinoh.styleds import *
 
@@ -83,6 +84,7 @@ matcher('block quote', GroupedFlowables.like('block quote'))
 #
 
 matcher('chapter', Section.like(level=1))
+matcher('content chapter', DocumentTree / ... / Section.like(level=1))
 
 for i in range(1, 6):
     matcher('heading level {}'.format(i), Heading.like(level=i))
@@ -334,6 +336,8 @@ matcher('table first column paragraph',
 matcher('table body cell list item number', SelectorByName('table cell')
                                             / ... / ListItem / Paragraph)
 matcher('table head cell', Table / TableHead / TableRow / TableCell)
+matcher('table head cell background', Table / TableHead / TableRow / TableCell
+                                      / TableCellBackground)
 matcher('table head cell paragraph', 'table head cell' / Paragraph)
 matcher('table cell left border', TableCellBorder.like(position='left'))
 matcher('table cell top border', TableCellBorder.like(position='top'))
