@@ -31,9 +31,10 @@ from ast import literal_eval
 from html.entities import name2codepoint
 from token import NAME, STRING, NEWLINE, LPAR, RPAR, ENDMARKER
 
+from .annotation import AnchorAnnotation, LinkAnnotation, AnnotatedSpan
 from .attribute import (AttributeType, AcceptNoneAttributeType, Attribute,
-                        Bool, Integer)
-from .color import Color, BLACK
+                        Bool, Integer, ParseError)
+from .color import Color, BLACK, RED
 from .dimension import Dimension, PT
 from .font import Typeface
 from .fonts import adobe14
@@ -75,17 +76,46 @@ class Locale(AttributeType):
 class InlineStyled(Styled):
     """"""
 
+    @property
+    def referenceable_ids(self):
+        try:
+            return self.parent.referenceable_ids
+        except AttributeError:
+            return [self.parent.referenceable.id,
+                    *self.parent.referenceable.secondary_ids]
+
+    def _annotated_spans(self, container):
+        spans = self.spans(container)
+        ann = self.get_annotation(container)
+        if not ann:
+            yield from spans
+            return
+        anchor = ann if isinstance(ann, AnchorAnnotation) else None
+        link = ann if isinstance(ann, LinkAnnotation) else None
+        for span in spans:
+            if isinstance(span, AnnotatedSpan):
+                if anchor and not span.anchor_annotation:
+                    span.anchor_annotation = anchor
+                elif link and not span.link_annotation:
+                    span.link_annotation = link
+                yield span
+            else:
+                yield AnnotatedSpan(span, anchor=anchor, link=link)
+
     def wrapped_spans(self, container):
         """Generator yielding all spans in this inline element (flattened)"""
         before = self.get_style('before', container)
         if before is not None:
             yield from before.copy(self.parent).wrapped_spans(container)
         if not self.get_style('hide', container):
-            yield from self.spans(container)
+            yield from self._annotated_spans(container)
         after = self.get_style('after', container)
         if after is not None:
             yield from after.copy(self.parent).wrapped_spans(container)
 
+    def is_title_reference(self, container):
+        return False
+
     def copy(self, parent=None):
         raise NotImplementedError
 
@@ -256,7 +286,7 @@ class StyledText(InlineStyled, AcceptNoneAttributeType):
         return [self]
 
 
-class StyledTextParseError(Exception):
+class StyledTextParseError(ParseError):
     pass
 
 
@@ -652,5 +682,13 @@ class Subscript(MixedStyledText):
                          source=source)
 
 
+ERROR_STYLE = TextStyle(font_color=RED)
+
+
+class ErrorText(SingleStyledText):
+    def __init__(self, text, style=ERROR_STYLE, parent=None, source=None):
+        super().__init__(text, style=style, parent=parent, source=source)
+
+
 from .reference import Field
 from .inline import InlineFlowable
