@@ -13,32 +13,24 @@ from warnings import formatwarning as standard_formatwarning
 from warnings import showwarning as standard_showwarning
 
 
-class RinohWarning(Warning):
+class RinohWarning(UserWarning):
     @property
     def message(self):
         return self.args[0]
 
 
 def warn(message):
-    warnings.warn(RinohWarning(message))
-
-
-def formatwarning(warning, category, filename, lineno, line=None):
-    if category == RinohWarning:
-        return '{}\n'.format(warning.message)
-    else:
-        return standard_formatwarning(warning, category, filename, lineno, line)
+    warnings.warn(message, category=RinohWarning, stacklevel=2)
 
 
 def showwarning(warning, category, filename, lineno, file=None, line=None):
     if category == RinohWarning:
         if file is None:
             file = sys.stderr
-        file.write('\r' + formatwarning(warning, category, filename, line))
+        file.write('\r{}\n'.format(warning.message))
     else:
         return standard_showwarning(warning, category, filename, lineno, file,
                                     line)
 
 
-warnings.formatwarning = formatwarning
 warnings.showwarning = showwarning
