@@ -12,12 +12,12 @@ from rinoh.attribute import Var
 from rinoh.color import HexColor
 from rinoh.dimension import PT, CM
 from rinoh.document import DocumentTree, Document, FakeContainer
+from rinoh.flowable import GroupedFlowables, StaticGroupedFlowables
 from rinoh.font import FontWeight, FontSlant, FontWidth
 from rinoh.language import EN
 from rinoh.paragraph import Paragraph, ParagraphStyle
 from rinoh.text import StyledText, SingleStyledText
-from rinoh.style import StyleSheet, StyledMatcher
-
+from rinoh.style import StyleSheet, StyledMatcher, PARENT_STYLE, NEXT_STYLE
 
 emphasis_selector = StyledText.like('emphasis')
 emphasis2_selector = StyledText.like('emphasis2')
@@ -27,6 +27,9 @@ paragraph_selector = Paragraph
 paragraph2_selector = Paragraph.like('paragraph2')
 paragraph3_selector = Paragraph.like('paragraph3')
 paragraph4_selector = Paragraph.like('paragraph4')
+grouped1_selector = GroupedFlowables.like('grouped1')
+paragraph6_selector = grouped1_selector / Paragraph
+paragraph7_selector = grouped1_selector / Paragraph.like('paragraph7')
 missing_selector = Paragraph.like('missing')
 
 matcher = StyledMatcher({
@@ -37,6 +40,8 @@ matcher = StyledMatcher({
     'paragraph': paragraph_selector,
     'paragraph 2': paragraph2_selector,
     'paragraph 4': paragraph4_selector,
+    'grouped 1': grouped1_selector,
+    'paragraph 6': paragraph6_selector,
     'missing style': missing_selector,
 })
 
@@ -70,11 +75,17 @@ ssheet1('paragraph 4',
         base='paragraph',
         padding_top=5*PT,
         before=SingleStyledText('before p4'))
+ssheet1('grouped 1',
+        padding_top=3*PT)
+ssheet1('paragraph 6',
+        base=NEXT_STYLE,
+        space_above=6*PT)
 
 
 
 matcher2 = StyledMatcher({
     'paragraph 3': paragraph3_selector,
+    'paragraph 7': paragraph7_selector,
 })
 
 ssheet2 = StyleSheet('ssheet2', base=ssheet1, matcher=matcher2)
@@ -94,6 +105,9 @@ ssheet2('paragraph 3',
         margin_left=1*PT)
 ssheet2['paragraph 4'] = ParagraphStyle(padding_right=2*PT,
                                         after=SingleStyledText('after p4'))
+ssheet2('paragraph 7',
+        base=PARENT_STYLE,
+        margin_left=7*PT)
 
 
 highlighted = SingleStyledText('highlighed', style='highlight')
@@ -110,10 +124,12 @@ paragraph4 = Paragraph('A fourth paragraph.', style='paragraph4')
 paragraph5 = Paragraph('A paragraph for which no style is present in the '
                        'style sheet', style='missing')
 paragraph6 = Paragraph('A sixth paragraph with ' + highlighted + ' text.')
-paragraph7 = Paragraph('A seventh paragraph with ' + highlighted2 + ' text.')
+paragraph7 = Paragraph('A seventh paragraph with ' + highlighted2 + ' text.',
+                       style='paragraph7')
+grouped1 = StaticGroupedFlowables([paragraph6, paragraph7], style='grouped1')
 
 doctree = DocumentTree([paragraph, paragraph2, paragraph3, paragraph4,
-                        paragraph5, paragraph6, paragraph7])
+                        paragraph5, grouped1])
 
 document = Document(doctree, ssheet2, EN)
 container = FakeContainer(document)
@@ -156,24 +172,30 @@ def test_get_selector():
     assert ssheet2.get_selector('paragraph 2') == paragraph2_selector
     assert ssheet2.get_selector('paragraph 3') == paragraph3_selector
     assert ssheet2.get_selector('paragraph 4') == paragraph4_selector
+    assert ssheet2.get_selector('grouped 1') == grouped1_selector
+    assert ssheet2.get_selector('paragraph 7') == paragraph7_selector
     assert ssheet2.get_selector('missing style') == missing_selector
 
 
-def test_find_style():
+def test_get_matches():
     assert ssheet2.get_value_for(emphasized, 'font_slant', document) == FontSlant.ITALIC
     assert ssheet2.get_value_for(paragraph5, 'font_slant', document) == FontSlant.UPRIGHT
 
-    assert ssheet1.find_style(emphasized, document) == 'emphasized text'
-    assert ssheet1.find_style(emphasized2, document) == 'emphasized text 2'
-    assert ssheet1.find_style(paragraph, document) == 'paragraph'
-    assert ssheet2.find_style(paragraph, document) == 'paragraph'
-    assert ssheet1.find_style(paragraph2, document) == 'paragraph 2'
-    assert ssheet2.find_style(paragraph2, document) == 'paragraph 2'
-    assert ssheet1.find_style(paragraph3, document) == 'paragraph'
-    assert ssheet2.find_style(paragraph3, document) == 'paragraph 3'
-    assert ssheet1.find_style(paragraph4, document) == 'paragraph 4'
-    assert ssheet2.find_style(paragraph4, document) == 'paragraph 4'
-    assert ssheet2.find_style(paragraph5, document) == 'paragraph'
+    def helper(element):
+        return [(match.style_name, match.stylesheet)
+                for match in document.get_matches(element)]
+
+    assert helper(emphasized) == [('emphasized text', 'ssheet1')]
+    assert helper(emphasized2) == [('emphasized text 2', 'ssheet1')]
+    assert helper(paragraph) == [('paragraph', 'ssheet2')]
+    assert helper(paragraph2) == [('paragraph 2', 'ssheet1'),
+                                  ('paragraph', 'ssheet2')]
+    assert helper(paragraph3) == [('paragraph 3', 'ssheet2'),
+                                  ('paragraph', 'ssheet2')]
+    assert helper(paragraph4) == [('paragraph 4', 'ssheet2'),
+                                  ('paragraph', 'ssheet2')]
+    assert helper(paragraph5) == [('missing style', None),
+                                  ('paragraph', 'ssheet2')]
 
 
 def test_get_style():
@@ -244,9 +266,16 @@ def test_get_style():
     after_p4 = paragraph4.get_style('after', container)
     assert after_p4 == SingleStyledText('after p4', source=ssheet2)
 
+    assert grouped1.get_style('padding_top', container) == 3*PT
+    assert paragraph6.get_style('space_above', container) == 6*PT
+    assert paragraph6.get_style('font_size', container) == 8*PT
+    assert paragraph7.get_style('margin_left', container) == 7*PT
+    assert paragraph7.get_style('padding_top', container) == 3*PT
+
 
 def test_variable():
     assert emphasized.get_style('font_size', container) == 20*PT
+    assert emphasized.get_style('font_color', container) == HexColor('f00')
     assert emphasized2.get_style('font_size', container) == 20*PT
     assert emphasized3.get_style('font_size', container) == 20*PT
 
